health.survey.data<- read.csv(file="./Example4.1Data.csv", header=TRUE, sep=",")

#install.packages("ordinal")
library(ordinal)

#specifying reference categories
gender.rel<- relevel(as.factor(health.survey.data$gender), ref="M")
marital.rel<- relevel(as.factor(health.survey.data$marital), ref="yes")
educ.rel<- relevel(as.factor(health.survey.data$educ), ref="HSgrad+")
health.rel<- relevel(as.factor(health.survey.data$health), ref="1poor")

#fitting cumulative complementary log-log model
summary(fitted.model<- clm(health.rel ~ gender.rel + age + marital.rel + educ.rel,
data=health.survey.data, link="cloglog"))

#extracting AICC and BIC for fitted model
p<- 8
n<- 32
print(AICC<- -2*logLik(fitted.model)+2*p*n/(n-p-1))
BIC(fitted.model)

#checking model fit
null.model<- clm(health.rel ~ 1, data=health.survey.data, link="cloglog")
print(deviance<- -2*(logLik(null.model)-logLik(fitted.model)))
print(p.value<- pchisq(deviance, df=5, lower.tail=FALSE))

#using fitted model for prediction
print(predict(fitted.model, data.frame(gender.rel="M", age=52, 
marital.rel="yes", educ.rel="HSgrad"), type="prob"))


